@@ -15,7 +15,13 @@ def copy_asset(project, asset):
 
     for include in asset.includes:
 
-        from_dir = os.path.abspath("{0}/{1}/{2}".format(project.repository_path, asset.name, include.dir))
+        # if iclude dir is specified include that path, otherwise
+        # just use the path to the asset in the repository
+        if (include.dir):
+            from_dir = os.path.abspath("{0}/{1}/{2}".format(project.repository_path, asset.name, include.dir))
+        else:
+            from_dir = os.path.abspath("{0}/{1}".format(project.repository_path, asset.name))
+
         to_dir = os.path.abspath("{0}/{1}".format(project.project_path, include.todir))
 
         if not os.path.exists(from_dir):
@@ -29,11 +35,11 @@ def copy_asset(project, asset):
 
         try:
             copy_tree(from_dir, to_dir)
-            # ret = copy_tree(from_dir, to_dir, dry_run=1, )
-            # print(ret)
         except Exception as e:
             raise Exception(e)
 
+        return 
+
 
 #   pull asset from location
 def pull_asset(project, asset):
